@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 1, 0)
+__version__ = (0, 1, 2)
 __all__ = [
     "SupportsGeturl", "url_origin", "complete_url", "ensure_ascii_url", 
     "urlencode", "cookies_str_to_dict", "headers_str_to_dict_by_lines", 
@@ -124,6 +124,7 @@ def urlencode(
     /, 
     encoding: str = "utf-8", 
     errors: str = "strict", 
+    ensure_ascii: bool = True, 
 ) -> str:
     if isinstance(payload, str):
         return payload
@@ -139,14 +140,20 @@ def urlencode(
                 k = str(k, encoding, errors)
             else:
                 k = str(k)
-            yield k.translate(QUERY_KEY_TRANSTAB)
+            if ensure_ascii:
+                yield quote(k)
+            else:
+                yield k.translate(QUERY_KEY_TRANSTAB)
             yield "="
             if v is True:
                 yield "true"
+                continue
             elif v is False:
                 yield "false"
+                continue
             elif v is None:
                 yield "null"
+                continue
             elif isinstance(v, (str, UserString)):
                 pass
             elif isinstance(v, Buffer):
@@ -155,7 +162,10 @@ def urlencode(
                 v = json_dumps(v, default=json_default).decode("utf-8")
             else:
                 v = str(v)
-            yield v.replace("&", "%26")
+            if ensure_ascii:
+                yield quote(v)
+            else:
+                yield v.replace("&", "%26")
     return "".join(encode_iter(iter_items(payload)))
 
 
@@ -287,12 +297,10 @@ def encode_multipart_data(
     def encode_iter() -> Iterator[Buffer]:
         if data:
             for name, value in iter_items(data):
-                yield boundary_line
                 yield from encode_item(name, value)
                 yield b"\r\n"
         if files:
             for name, value in iter_items(files):
-                yield boundary_line
                 yield from encode_item(name, value, is_file=True)
                 yield b"\r\n"
         yield b'--%s--\r\n' % boundary_bytes
@@ -382,13 +390,11 @@ def encode_multipart_data_async(
     async def encode_iter() -> AsyncIterator[Buffer]:
         if data:
             for name, value in iter_items(data):
-                yield boundary_line
                 async for line in encode_item(name, value):
                     yield line
                 yield b"\r\n"
         if files:
             for name, value in iter_items(files):
-                yield boundary_line
                 async for line in encode_item(name, value, is_file=True):
                     yield line
                 yield b"\r\n"
@@ -425,7 +431,7 @@ def normalize_request_args(
     json: Any = None, 
     files: None | Mapping[string, Any] | Iterable[tuple[string, Any]] = None, 
     headers: None | Mapping[string, Any] | Iterable[tuple[string, Any]] = None, 
-    ensure_ascii: bool = False, 
+    ensure_ascii: bool = True, 
     *, 
     async_: bool = False, 
 ) -> RequestArgs:
@@ -435,7 +441,7 @@ def normalize_request_args(
     elif isinstance(url, URL):
         url = str(url)
     url = complete_url(ensure_str(url))
-    if params and (params := urlencode(params)):
+    if params and (params := urlencode(params, ensure_ascii=ensure_ascii)):
         urlp = urlparse(url)
         if query := urlp.query:
             params = query + "&" + params
@@ -450,7 +456,7 @@ def normalize_request_args(
     content_type = headers_.get("content-type", "")
     charset      = get_charset(content_type)
     mimetype     = get_mimetype(charset).lower()
-    if files is not None:
+    if files:
         headers2, data = encode_multipart_data(
             cast(None | Mapping[string, Any] | Iterable[tuple[string, Any]], data), 
             files, 
@@ -477,7 +483,7 @@ def normalize_request_args(
                 data = dumps(data, default=json_default).encode(charset)
         elif isinstance(data, (Mapping, Sequence)):
             if data:
-                data = urlencode(data, charset).encode(charset)
+                data = urlencode(data, charset, ensure_ascii=ensure_ascii).encode(charset)
                 if mimetype != "application/x-www-form-urlencoded":
                     headers_["content-type"] = "application/x-www-form-urlencoded"
         else:
